@@ -103,8 +103,6 @@ void draw_window(Window win)
 			1,
 			1
 			);
-	}
-	if ( state.draw_date ) {
 		XCopyArea(
 			mainDisplay,
 			digitsXpm.pixmap,
@@ -287,6 +285,7 @@ void calculate_pointers()
 void refresh()
 {
 	calculate_pointers();
+	draw_window(drawWindow);
 	++update_request;
 }
 
@@ -344,9 +343,6 @@ void CheckX11Events()
 
 void redraw()
 {
-	draw_window(drawWindow);
-/*	draw_window(mainWindow);
-	draw_window(iconWindow);*/
         XCopyArea(
                 mainDisplay,
                 drawWindow,
@@ -387,6 +383,124 @@ void update()
 	}
 }
 
+/* Draw those little points every 5 secs on the background pixmap
+ * that usually are marked 1,2,3,4,5,6,7 etc.
+ * And those triangles that mark 3,6,9,12 o'clock */
+void draw_dial()
+{
+	int tmp;
+	struct coordinates tmp_coord;
+	float xrate, yrate;
+
+	mainGCV.foreground = fore_pix;
+        XChangeGC(
+                mainDisplay,
+                mainGC,
+                GCForeground,
+                &mainGCV
+                );
+	for (tmp = 0; tmp < 60; tmp += 5) {
+		xrate = convert2x(tmp);
+		yrate = convert2y(tmp);
+		tmp_coord.x = rint((watch_size.x+1) * xrate) + center.x;
+		tmp_coord.y = rint((watch_size.y+1) * yrate) + center.y;
+#ifdef DEBUG
+		printf("dot at %d %d\n", tmp_coord.x, tmp_coord.y);
+#endif
+		XDrawPoint(
+			mainDisplay,
+			backgroundWindow,
+			mainGC,
+			tmp_coord.x,
+			tmp_coord.y
+			);
+	}
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x-watch_size.x-1,
+		center.y-1
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x-watch_size.x-1,
+		center.y+1
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x-watch_size.x,
+		center.y
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x+watch_size.x+1,
+		center.y-1
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x+watch_size.x+1,
+		center.y+1
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x+watch_size.x,
+		center.y
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x-1,
+		center.y-watch_size.y-1
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x+1,
+		center.y-watch_size.y-1
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x,
+		center.y-watch_size.y
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x-1,
+		center.y+watch_size.y+1
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x+1,
+		center.y+watch_size.y+1
+		);
+	XDrawPoint(
+		mainDisplay,
+		backgroundWindow,
+		mainGC,
+		center.x,
+		center.y+watch_size.y
+		);
+}
+
 void initialize(
 			int argc, char** argv,
 			char * display_name,
@@ -406,9 +520,6 @@ void initialize(
 	XWMHints WmHints;
 	XEvent Event;
 	int color_depth;
-	int tmp;
-	struct coordinates tmp_coord;
-	float xrate, yrate;
 	Pixel tmp_pix;
 	int result;
 
@@ -428,24 +539,17 @@ void initialize(
 			state.total_size.y = SizeHints.height;
 		}
 #ifdef DEBUG
-		printf("User size: %d x %d\n", 
-			state.total_size.x, state.total_size.y);
+		printf("User size: %d x %d, position: %d %d\n", 
+			state.total_size.x, state.total_size.y,
+			SizeHints.x, SizeHints.y);
 #endif
 	}
 	if (state.draw_date) {
-/*		center.x = 30;
-		center.y = 23;
-		watch_size.x = 20;
-		watch_size.y = 20;*/
-		center.x = state.total_size.x / 2 + 3;
+		center.x = state.total_size.x / 2;
 		center.y = state.total_size.y / 2 - 4;
-		watch_size.x = state.total_size.x / 2 - 7;
+		watch_size.x = center.x - 3;
 		watch_size.y = state.total_size.y / 2 - 7;
 	} else {
-/*		center.x = 27;
-		center.y = 27;
-		watch_size.x = 24;
-		watch_size.y = 24;*/
 		center.x = state.total_size.x / 2;
 		center.y = state.total_size.y / 2;
 		watch_size.x = center.x - 3;
@@ -527,8 +631,8 @@ void initialize(
         }       
 
         SizeHints.flags= USSize|USPosition|PMinSize|PMaxSize;
-        SizeHints.x = 0; 
-        SizeHints.y = 0; 
+        SizeHints.x = 0;
+        SizeHints.y = 0;
         XWMGeometry(
                 mainDisplay,
                 screen,
@@ -543,9 +647,10 @@ void initialize(
                 &gravity
                 );
 #ifdef DEBUG
-	printf("SizeHints were: %d x %d, setting to %d x %d\n",
+	printf("SizeHints were: %d x %d, setting to %d x %d, position %d %d\n",
 		SizeHints.width, SizeHints.height,
-		state.total_size.x, state.total_size.y);
+		state.total_size.x, state.total_size.y,
+		SizeHints.x, SizeHints.y);
 #endif
         SizeHints.min_width =
         SizeHints.max_width =
@@ -594,7 +699,7 @@ void initialize(
                 back_pix                /* background */
                 );
                 
-        /*XSetWMNormalHints(mainDisplay, mainWindow, &SizeHints);*/
+        XSetWMNormalHints(mainDisplay, mainWindow, &SizeHints);
         XSetWMNormalHints(mainDisplay, iconWindow, &SizeHints);
         status = XClearWindow(mainDisplay, mainWindow);
         status = XClearWindow(mainDisplay, iconWindow);
@@ -720,31 +825,9 @@ void initialize(
 		0,
 		state.total_size.y-1
 		);
-	/* Draw those little points every 5 secs on the background pixmap
-	 * that usually are marked 1,2,3,4,5,6,7 etc. */
-	mainGCV.foreground = fore_pix;
-        XChangeGC(
-                mainDisplay,
-                mainGC,
-                GCForeground,
-                &mainGCV
-                );
-	for (tmp = 0; tmp < 60; tmp += 5) {
-		xrate = convert2x(tmp);
-		yrate = convert2y(tmp);
-		tmp_coord.x = rint((watch_size.x+1) * xrate) + center.x;
-		tmp_coord.y = rint((watch_size.y+1) * yrate) + center.y;
-#ifdef DEBUG
-		printf("dot at %d %d\n", tmp_coord.x, tmp_coord.y);
-#endif
-		XDrawPoint(
-			mainDisplay,
-			backgroundWindow,
-			mainGC,
-			tmp_coord.x,
-			tmp_coord.y
-			);
-	}
+
+	/* Finish up the background (the dial) */
+	draw_dial();
 
         status = XSetCommand(mainDisplay, mainWindow, argv, argc);
         
@@ -801,8 +884,6 @@ void initialize(
 	pix[0] = GetColor(state.seccolor, mainDisplay, Root);
 	pix[1] = GetColor(state.mincolor, mainDisplay, Root);
 	pix[2] = GetColor(state.hourcolor, mainDisplay, Root);
-	/*pix[1] = DarkenColor(state.fgcolor, 1.2, mainDisplay, Root);
-	pix[2] = DarkenColor(state.fgcolor, 1.4, mainDisplay, Root);*/
 
 	/* try to read the time */
 	curTime = time(0);
